==> haskell-semialign-1.3.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semialign.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semialign
version:              1.3.1
visibility:           public
id:                   semialign-1.3.1-2HrjM3xVHz02Uc0MmBCt5K
key:                  semialign-1.3.1-2HrjM3xVHz02Uc0MmBCt5K
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  d0be0f992fc231ab6911375fc30ec45c
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/semialign-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/semialign-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/semialign-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.3.1-2HrjM3xVHz02Uc0MmBCt5K
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.6.0-2vEivDIcaMF9mfkC7wRjoU
    indexed-traversable-0.1.4-JYfisWLMyBh1BEfbVJsUp6
    indexed-traversable-instances-0.1.2-8eU0xXxk8f3CrsWfMNyA8F
    semigroupoids-6.0.1-20Td3TsVKPT7ywapKS1MKw
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    these-1.2.1-4VQanxuOgE02PoJiSIJOLj transformers-0.5.6.2
    unordered-containers-0.2.20-8z8yrOH3Dwd8Gc78vZRE2k
    vector-0.13.2.0-C8nzmtHpFSiD5klMFr8FFK

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-semialign-1.3.1-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-semialign.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 semialign
version:              1.3.1
visibility:           public
id:                   semialign-1.3.1-JvvoyQRKq1JDVfeqN8ULF5
key:                  semialign-1.3.1-JvvoyQRKq1JDVfeqN8ULF5
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               C. McCann, Oleg Grenrus
homepage:             https://github.com/haskellari/these
synopsis:
    Align and Zip type-classes from the common Semialign ancestor.

description:
    The major use of @These@ of this is provided by the @align@ member of
    @Semialign@ class, representing a generalized notion of "zipping with padding"
    that combines structures without truncating to the size of the smaller input.

    It turns out that @zip@ operation fits well the @Semialign@ class,
    forming lattice-like structure.

category:             Data, These
abi:                  b73ee707b7f23c121d30a90c8d8005ae
exposed:              True
exposed-modules:
    Data.Align Data.Crosswalk Data.Semialign Data.Semialign.Indexed
    Data.Zip

hidden-modules:       Data.Semialign.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/semialign-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/semialign-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/semialign-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-semialign
hs-libraries:         HSsemialign-1.3.1-JvvoyQRKq1JDVfeqN8ULF5
depends:
    base-4.17.2.1 containers-0.6.7
    hashable-1.4.6.0-HsdqsQ7iDyd40AcboGWr8K
    indexed-traversable-0.1.4-10ilYqh2nxEny8IgMDEXE
    indexed-traversable-instances-0.1.2-3Lpo417sWsdG9vAt59FHyz
    semigroupoids-6.0.1-ALhEB1ekwQkFChjKmHdaGN
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
    these-1.2.1-KJcqPYhYbjSEzRIYZM0lRq transformers-0.5.6.2
    unordered-containers-0.2.20-DjNgsRwGYvfHy5WsKzKUzR
    vector-0.13.2.0-FmAyOUuMvM2EH0h3dDhWXJ

haddock-interfaces:   /usr/share/doc/haskell-semialign/html/semialign.haddock
haddock-html:         /usr/share/doc/haskell-semialign/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
